@@ -840,17 +840,6 @@ take1WhileP f = T.pack <$> many1 (satisfy f)
 
 inBraces :: BibParser Text
 inBraces = do
-  char '{'
-  res <- manyTill
-         (  take1WhileP (\c -> c /= '{' && c /= '}' && c /= '\\' && c /= '%')
-        <|> (char '\\' >> T.cons '\\' . T.singleton <$> anyChar)
-        <|> ("" <$ (char '%' >> anyLine))
-        <|> (braced <$> inBraces)
-         ) (char '}')
-  return $ T.concat res
-
-inBracesURL :: BibParser Text
-inBracesURL = do
   char '{'
   res <- manyTill
          (  take1WhileP (\c -> c /= '{' && c /= '}' && c /= '\\')
@@ -864,21 +853,12 @@ braced = T.cons '{' . flip T.snoc '}'
 
 inQuotes :: BibParser Text
 inQuotes = do
-  char '"'
-  T.concat <$> manyTill
-             ( take1WhileP (\c -> c /= '{' && c /= '"' && c /= '\\' && c /= '%')
-               <|> (char '\\' >> T.cons '\\' . T.singleton <$> anyChar)
-               <|> ("" <$ (char '%' >> anyLine))
-               <|> braced <$> inBraces
-            ) (char '"')
-
-inQuotesURL :: BibParser Text
-inQuotesURL = do
   char '"'
   T.concat <$> manyTill
              ( take1WhileP (\c -> c /= '{' && c /= '"' && c /= '\\')
                <|> (char '\\' >> T.cons '\\' . T.singleton <$> anyChar)
-             ) (char '"')
+               <|> braced <$> inBraces
+            ) (char '"')
 
 fieldName :: BibParser Text
 fieldName = resolveAlias . T.toLower
@@ -915,9 +895,7 @@ entField = do
   spaces'
   char '='
   spaces'
-  let inQ = if k == "url" then inQuotesURL else inQuotes
-  let inB = if k == "url" then inBracesURL else inBraces
-  vs <- (expandString <|> inQ <|> inB <|> rawWord) `sepBy`
+  vs <- (expandString <|> inQuotes <|> inBraces <|> rawWord) `sepBy`
             try (spaces' >> char '#' >> spaces')
   spaces'
   return (k, T.concat vs)
